{
  inputs = {
    nixpkgs.url = "github:NixOS/nixpkgs/nixos-unstable";
    sops-nix.url = "github:Mic92/sops-nix";
    disko = {
      url = "github:nix-community/disko";
      inputs.nixpkgs.follows = "nixpkgs";
    };
    facter = {
      url = "github:nix-community/nixos-facter-modules";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = inputs: {
    nixosConfigurations.raid1base = import ./setup { inherit inputs; };
    colmena = {
      meta = {
        nixpkgs = import inputs.nixpkgs {
          system = "x86_64-linux";
          overlays = [ ];
        };
      };

      git-system =
        {
          name,
          nodes,
          pkgs,
          ...
        }:
        {
          deployment = {
            targetHost = "188.40.66.217";
            targetPort = 54222;
            targetUser = "root";
          };
          imports = [
            inputs.disko.nixosModules.disko

            ./git_system.nix

            ./setup/disk_conf.nix
            ./setup/mini_conf.nix
            {
              networking.hostId = "0a7337de";
              boot.loader.grub.zfsSupport = true;
            }
          ];
        };
      runner-system =
        {
          name,
          nodes,
          pkgs,
          ...
        }:
        {
          deployment = {
            targetHost = "157.90.133.118";
            targetPort = 54222;
            targetUser = "root";
          };
          imports = [
            inputs.disko.nixosModules.disko

            ./runner_system.nix

            ./setup/disk_conf.nix
            ./setup/mini_conf.nix
            {
              networking.hostId = "0a7337de";
              boot.loader.grub.zfsSupport = true;
            }
          ];
        };
      dev-system =
        {
          name,
          nodes,
          pkgs,
          ...
        }:
        {
          deployment = {
            targetHost = "88.99.218.181";
            targetPort = 54222;
            targetUser = "root";
          };
          imports = [
            inputs.disko.nixosModules.disko
            inputs.sops-nix.nixosModules.sops

            ./dev_system.nix

            ./setup/disk_conf.nix
            ./setup/mini_conf.nix
            {
              networking.hostId = "0a7337de";
              boot.loader.grub.zfsSupport = true;
            }
          ];
        };
    };
  };
}
